==> mediawiki-1.26.2-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/languages/messages/MessagesNap.php <==
<?php
/** Neapolitan (Napulitano)
 *
 * To improve a translation please visit https://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author C.R.
 * @author Carmine Colacino
 * @author Chelin
 * @author Cryptex
 * @author E. abu Filumena
 * @author PiRSquared17
 * @author SabineCretella
 * @author לערי ריינהארט
 */

$fallback = 'it';

$namespaceNames = array(
	NS_MEDIA            => 'Media',
	NS_SPECIAL          => 'Speciàle',
	NS_TALK             => 'Chiàcchiera',
	NS_USER             => 'Utente',
	NS_USER_TALK        => 'Utente_chiàcchiera',
	NS_PROJECT_TALK     => '$1_chiàcchiera',
	NS_FILE             => 'Fiùra',
	NS_FILE_TALK        => 'Fiùra_chiàcchiera',
	NS_MEDIAWIKI        => 'MediaWiki',
	NS_MEDIAWIKI_TALK   => 'MediaWiki_chiàcchiera',
	NS_TEMPLATE         => 'Modello',
	NS_TEMPLATE_TALK    => 'Modello_chiàcchiera',
	NS_HELP             => 'Ajùto',
	NS_HELP_TALK        => 'Ajùto_chiàcchiera',
	NS_CATEGORY         => 'Categurìa',
	NS_CATEGORY_TALK    => 'Categurìa_chiàcchiera',
);

$namespaceAliases = array(
	'Speciale' => NS_SPECIAL,
	'Discussione' => NS_TALK,
	'Utente' => NS_USER,
	'Discussioni_utente' => NS_USER_TALK,
	'Discussioni_$1' => NS_PROJECT_TALK,
	'Immagine' => NS_FILE,
	'Discussioni_immagine' => NS_FILE_TALK,
	'MediaWiki' => NS_MEDIAWIKI,
	'Discussioni_MediaWiki' => NS_MEDIAWIKI_TALK,
	'Discussioni_template' => NS_TEMPLATE_TALK,
	'Aiuto' => NS_HELP,
	'Discussioni_aiuto' => NS_HELP_TALK,
	'Categoria' => NS_CATEGORY,
	'Discussioni_categoria' => NS_CATEGORY_TALK,
);

==> mediawiki-1.27.1-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/languages/messages/MessagesNap.php <==
<?php
/** Neapolitan (Napulitano)
 *
 * To improve a translation please visit https://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author C.R.
 * @author Carmine Colacino
 * @author Chelin
 * @author Cryptex
 * @author E. abu Filumena
 * @author PiRSquared17
 * @author SabineCretella
 * @author לערי ריינהארט
 */

$fallback = 'it';

$namespaceNames = [
	NS_MEDIA            => 'Media',
	NS_SPECIAL          => 'Speciàle',
	NS_TALK             => 'Chiàcchiera',
	NS_USER             => 'Utente',
	NS_USER_TALK        => 'Utente_chiàcchiera',
	NS_PROJECT_TALK     => '$1_chiàcchiera',
	NS_FILE             => 'Fiùra',
	NS_FILE_TALK        => 'Fiùra_chiàcchiera',
	NS_MEDIAWIKI        => 'MediaWiki',
	NS_MEDIAWIKI_TALK   => 'MediaWiki_chiàcchiera',
	NS_TEMPLATE         => 'Modello',
	NS_TEMPLATE_TALK    => 'Modello_chiàcchiera',
	NS_HELP             => 'Ajùto',
	NS_HELP_TALK        => 'Ajùto_chiàcchiera',
	NS_CATEGORY         => 'Categurìa',
	NS_CATEGORY_TALK    => 'Categurìa_chiàcchiera',
];

$namespaceAliases = [
	'Speciale' => NS_SPECIAL,
	'Discussione' => NS_TALK,
	'Utente' => NS_USER,
	'Discussioni_utente' => NS_USER_TALK,
	'Discussioni_$1' => NS_PROJECT_TALK,
	'Immagine' => NS_FILE,
	'Discussioni_immagine' => NS_FILE_TALK,
	'MediaWiki' => NS_MEDIAWIKI,
	'Discussioni_MediaWiki' => NS_MEDIAWIKI_TALK,
	'Discussioni_template' => NS_TEMPLATE_TALK,
	'Aiuto' => NS_HELP,
	'Discussioni_aiuto' => NS_HELP_TALK,
	'Categoria' => NS_CATEGORY,
	'Discussioni_categoria' => NS_CATEGORY_TALK,
];
